@@ -35,7 +35,7 @@ class Parser:
     def xPath(self, path: str, element: any=None, pos: int=None, dataType: str=None, prop: str=None, explode=None, condition=None, substring=None, transform=None, replace=None, join=None, timeout=0, is_error: bool=True):
         return self.scraper.xPath(path=path, element=element, pos=pos, dataType=dataType, prop=prop, explode=explode, condition=condition, substring=substring, transform=transform, replace=replace, join=join, timeout=timeout, is_error=is_error)
 
-    def exists(self, path: str, element: any=None, timeout: int=0, is_error: bool=True):
+    def exists(self, path: str, element: any=None, timeout: int=0, is_error: bool=False):
         return self.scraper.exists(path=path, element=element, timeout=timeout, is_error=is_error)
 
     def get_css(self, element: any, prop: str):
