@@ -110,8 +110,8 @@ class Selenium(Scraper):
         if timeout > 0:
             try:
                 ignored_exceptions = (NoSuchElementException, StaleElementReferenceException)
-                return WebDriverWait(driver=element, timeout=timeout, ignored_exceptions=ignored_exceptions).until(
-                    EC.presence_of_element_located((By.XPATH, path))
+                return len(WebDriverWait(driver=element, timeout=timeout, ignored_exceptions=ignored_exceptions).until(
+                    EC.presence_of_element_located((By.XPATH, path))) > 0
                 )
             except Exception as ex:
                 if is_error is True: raise NoSuchElementException(msg=f'Element with xpath {path} was not found')
